from django.contrib import admin
from django.contrib.sites.models import Site

from polynum.base.models import *

class ProfileAdmin(admin.ModelAdmin):
    filter_horizontal = [ 'choices', ]
    list_display = ['name', 'display_choices', 'ppd', 'ppp']

admin.site.register(Profile, ProfileAdmin)

class ProfileOptionChoiceInline(admin.TabularInline):
    model = ProfileOptionChoice

class ProfileOptionAdmin(admin.ModelAdmin):
    inlines = [ ProfileOptionChoiceInline, ]
    list_display = ['name', 'list_type', 'display_choices']

admin.site.register(ProfileOption, ProfileOptionAdmin)

class ChildrenRelationInline(admin.TabularInline):
    model = EntityRelation
    fk_name = 'parent'

class ParentRelationInline(admin.TabularInline):
    model = EntityRelation
    fk_name = 'child'


class EntityAdmin(admin.ModelAdmin):
    list_display = ['code', 'name', 'get_accounting', 'description']
    search_fields = ['name', 'description', 'code', 'accounting']
    inlines = [ChildrenRelationInline, ParentRelationInline]

admin.site.register(Entity, EntityAdmin)

admin.site.register(RoleAssociation)
admin.site.register(ActionAssociation)
admin.site.register(RequestStatus)

admin.site.register(DeliveryPlace)
admin.site.register(Request)

admin.site.register(DocumentUsage)
admin.site.register(DocumentLicence)
admin.site.register(Document)

# don't show the "Site" model
admin.site.unregister(Site)

