# -*- coding: utf-8 -*-
"""
PolyNum

Définition des entités administratives
"""

from django.db import models
from django.utils.translation import ugettext_lazy as _

class Entity(models.Model):

    class Meta:
        app_label = 'base'
        verbose_name = _(u'Entité administrative')
        verbose_name_plural = _(u'Entités administratives')
        ordering = ('code',)

    def __unicode__(self):
        return u'%s (%s)' % (self.code, self.description)

    code = models.CharField(primary_key=True, max_length=64, verbose_name=_(u'Code'))
    name = models.CharField(max_length=128, verbose_name=_(u'Nom'), blank=True)
    accounting = models.CharField(max_length=128, verbose_name=_(u'Centre financier'), blank=True)
    description = models.TextField(verbose_name=_(u'Description'), blank=True)

    def get_accounting(self):
        if self.accounting:
            return self.accounting
        if 0 < self.parents.count() <= 1:
            return self.parents.get().get_accounting()
        else:
            raise ValueError('no accounting code')
    get_accounting.short_description = _(u'Centre financier')

    def children(self):
        return Entity.objects.filter(parent_relations__parent=self)

    def parents(self):
        return Entity.objects.filter(children_relations__child=self)

class EntityRelation(models.Model):
    parent = models.ForeignKey(Entity, related_name='children_relations', verbose_name=_(u'Entité parente'), on_delete=models.DO_NOTHING)
    child  = models.ForeignKey(Entity, related_name='parent_relations', verbose_name=_(u'Entité fille'), on_delete=models.DO_NOTHING)
    direct = models.BooleanField(default=True, blank=True)

    class Meta:
        app_label = 'base'
