# -*- coding: utf-8 -*-

from django.db import models
from django.utils.translation import ugettext_lazy as _

from decimal import Decimal
Zero = Decimal('0.00')


class ProfileOption(models.Model):

    class Meta:
        app_label = 'base'
        verbose_name = _(u"Profils d'impression : Option")
        verbose_name_plural = _(u"Profils d'impression : Options")

    def __unicode__(self):
        return self.name

    TYPE_CHOICES = (
            ('R', 'Radio (choix unique)'),
            ('L', 'Liste (choix unique)'),
            ('C', 'Cases à cocher (choix multiple)'),
            ('LM', 'Liste (choix multiple)'),
    )

    name = models.CharField(max_length=128, verbose_name=_(u"Nom de l'option de profil d'impression"))
    list_type = models.CharField(max_length=2, choices=TYPE_CHOICES, verbose_name=_(u'Type de liste de choix'))
    description = models.TextField(verbose_name=_(u'Description'), blank=True)

    def display_choices(self):
        return u', '.join([c.name for c in self.profileoptionchoice_set.all()])
    display_choices.short_description = 'Choix possibles'


class ProfileOptionChoice(models.Model):

    class Meta:
        app_label = 'base'
        verbose_name = _(u"Profils d'impression : Choix")
        verbose_name_plural = _(u"Profils d'impression : Choix")

    def __unicode__(self):
        return u'%s: %s' % (self.option.name, self.name)

    name = models.CharField(max_length=128, verbose_name=_(u'Nom du choix'))
    option = models.ForeignKey(ProfileOption, verbose_name=_(u'Option de profil à laquelle ce choix est lié'))
    ppp = models.DecimalField(max_digits=7, decimal_places=3,
            verbose_name=_(u'Prix par page (en euros)'), default=Zero)
    ppd = models.DecimalField(max_digits=7, decimal_places=3,
            verbose_name=_(u'Prix par document (en euros)'), default=Zero)
    description = models.TextField(verbose_name=_(u'Description'), blank=True)


class Profile(models.Model):

    class Meta:
        app_label = 'base'
        verbose_name = _(u"Profil d'impression")
        verbose_name_plural = _(u"Profils d'impression")

    def __unicode__(self):
        return self.name

    name = models.CharField(max_length=128, verbose_name=_(u"Nom du profil d'impression"))
    choices = models.ManyToManyField(ProfileOptionChoice, verbose_name=_(u'Choix associés au profil'), blank=True)
    ppp = models.DecimalField(max_digits=7, decimal_places=3,
            verbose_name=_(u'Prix par page (en euros)'), default=Zero)
    ppd = models.DecimalField(max_digits=7, decimal_places=3,
            verbose_name=_(u'Prix par document (en euros)'), default=Zero)
    description = models.TextField(verbose_name=_(u'Description'), blank=True)

    def display_choices(self):
        li = u''.join([u'<li>%s</li>' % c for c in self.choices.order_by('option').all()])
        return '<ul>%s</ul>' % li
    display_choices.short_description = 'Choix associés au profil'
    display_choices.allow_tags = True


