from django.conf import settings
from django.shortcuts import redirect
from django.contrib.formtools.wizard.views import NamedUrlSessionWizardView
from django.core.files.storage import FileSystemStorage
from django.contrib.auth.decorators import login_required

from forms import DocumentUploadForm, DocumentDetailsForm, ReproDetailsForm, \
                    DeliveryForm, CopyrigtsForm, ValidationForm

# https://github.com/mfenniak/pyPdf
from pyPdf import PdfFileReader

named_new_request_forms = (
    ('document_upload', DocumentUploadForm),
    ('document_details', DocumentDetailsForm),
    ('reprography', ReproDetailsForm),
    ('delivery', DeliveryForm),
    ('copyrights', CopyrigtsForm),
    ('validation', ValidationForm),
)


class RequestWizardView(NamedUrlSessionWizardView):

    template_name = 'new_request.html'
    file_storage = FileSystemStorage(location = settings.DOCUMENTS_UPLOAD_DIRECTORY)

    def get_template_names(self):
        return ['%s.%s' % (self.steps.current, self.template_name), self.template_name]

    def done(self, form_list, **kwargs):
        # TODO: do_something_with_the_form_data(form_list)
        return redirect('/request-done')

    def get_form_initial(self, step):
        initial = super(RequestWizardView, self).get_form_initial(step=step) or {}
        if step == 'document_details':
            upload_step = self.get_cleaned_data_for_step('document_upload') or {}
            docfile = upload_step.get('document_file', '')
            if docfile is None:
                initial['document_pages'] = '?'
            else:
                try:
                    pdf_file = PdfFileReader(docfile)
                    pdf_info = pdf_file.documentInfo
                    initial['document_title'] = u'%s' % pdf_info.get('/Title')
                    if pdf_info.get('/Subject'):
                        initial['document_title'] += ' - %s' % pdf_info.get('/Subject')
                    initial['document_pages'] = pdf_file.numPages
                except:
                    pass
        return initial

    def get_context_data(self, form, **kwargs):
        '''
        Add all_forms = list of (step, form, pprint_data), where pprint_data is
        a list of (name, value) created by each form, representing a "nice"
        view of the stored datas
        '''
        context = super(RequestWizardView, self).get_context_data(form=form, **kwargs)
        # cleaned_data = self.get_all_cleaned_data() or {}
        all_forms = []
        validated = True
        for step, form in self.get_form_list().items():
            cleaned_data = self.get_cleaned_data_for_step(step)
            if (step != self.steps.last) and (cleaned_data is None):
                validated = False
            if cleaned_data and hasattr(form, 'pprint_data'):
                pprint_data = form().pprint_data(cleaned_data)
            else:
                pprint_data = []
            all_forms += [ (step, form, pprint_data) ]
        context['all_forms'] = all_forms
        context['validated'] = validated
        return context


new_request_wizard = login_required(RequestWizardView.as_view(named_new_request_forms,
                                url_name='new_request_step',
                                done_step_name='new_request_finished'))

